<?php
/**
 * buzz-agency functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Buzz_Agency
 */

if ( ! function_exists( 'buzz_agency_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function buzz_agency_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on buzz-agency, use a find and replace
		 * to change 'buzz-agency' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'buzz-agency', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );
		add_image_size('buzz-agency-service-image', 95, 95 , true);

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'menu-1' => esc_html__( 'Primary', 'buzz-agency' ),
			'social-media'  => esc_html__( 'Social Media', 'buzz-agency' ),
			'footer-menu'  => esc_html__( 'Footer Menu', 'buzz-agency' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'buzz_agency_custom_background_args', array(
			'default-color' => '#ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
		
	}
endif;
add_action( 'after_setup_theme', 'buzz_agency_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function buzz_agency_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'buzz_agency_content_width', 640 );
}
add_action( 'after_setup_theme', 'buzz_agency_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function buzz_agency_widgets_init() {

	register_sidebar( array(
		'name'          => esc_html__( 'Right Sidebar', 'buzz-agency' ),
		'id'            => 'buzz-agency-sidebar-right',
		'description'   => esc_html__( 'Add widgets here.', 'buzz-agency' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
		)
    );
	register_sidebar( array(
		'name'          => esc_html__( 'Left Sidebar', 'buzz-agency' ),
		'id'            => 'buzz-agency-sidebar-left',
		'description'   => esc_html__( 'Add widgets here.', 'buzz-agency' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
		)
	 );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer One', 'buzz-agency' ),
		'id'            => 'buzz-agency-footer_one',
		'description'   => esc_html__( 'Add widgets here.', 'buzz-agency' ),
		'before_widget' => '<section id="%1$s" class="widget Title %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
		) 
	);
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Two', 'buzz-agency' ),
		'id'            => 'buzz-agency-footer-two',
		'description'   => esc_html__( 'Add widgets here.', 'buzz-agency' ),
		'before_widget' => '<div id="%1$s" class=" widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
		) 
	);
	register_sidebar( array(
		'name'          => esc_html__( 'Menu Cart', 'buzz-agency' ),
		'id'            => 'buzz-agency-menu-cart',
		'description'   => esc_html__( 'Add widgets here.', 'buzz-agency' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'buzz_agency_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function buzz_agency_scripts() {

	$buzz_agency_font_args = array(

	'family' => 'Muli:200,200i,300,300i,400,400i,600,600i,700i,800,800i,900,900i',
	);

	wp_enqueue_style( 'buzz-agency-google-fonts', add_query_arg( $buzz_agency_font_args, "//fonts.googleapis.com/css" ) );


	//Load Font Awesome  CSS
	wp_enqueue_style( 'fontawesome', get_template_directory_uri().'/assets/css/font-awesome.css',array(), '4.7.0 ', 'all' );

    wp_enqueue_style( 'owl-carousel', get_template_directory_uri().'/assets/css/owl.carousel.min.css',array(), 'v2.3.4', 'all' );

	// Load wol carousel 
    wp_enqueue_style( 'owl-carousel', get_template_directory_uri().'/assets/css/owl.carousel.min.css',array(), 'v2.3.4', 'all' );

    // Load wol theme
    wp_enqueue_style( 'owl-theme', get_template_directory_uri().'/assets/css/owl.theme.css',array(), 'v2.2.0', 'all' );

    // Load wol theme Default
    wp_enqueue_style( 'owl-theme-default', get_template_directory_uri().'/assets/css/owl.theme.default.min.css',array(), 'v2.3.4', 'all' );

    // Load Animations
    wp_enqueue_style( 'animaton', get_template_directory_uri().'/assets/css/animation.css',array(), '1.0.0', 'all' );


	wp_enqueue_style( 'buzz-agency-style', get_stylesheet_uri() );

	// Load wol carousel 
	wp_enqueue_script( 'jquery-owl-carousel', get_template_directory_uri().'/assets/js/owl.carousel.min.js', array( 'jquery' ), 'v1.7.0', false );

	// Load Portfolio
	wp_enqueue_script( 'buzz-agency-portfolio', get_template_directory_uri().'/assets/js/portfolio.js', array( 'jquery' ), 'v1.0.0', false );

	// Load Waypoints
	wp_enqueue_script( 'jquery-waypoint', get_template_directory_uri().'/assets/js/waypoint.min.js', array( 'jquery' ), 'v2.0.3 ', false );

	// Load Wow
	wp_enqueue_script( 'jquery-wow', get_template_directory_uri().'/assets/js/wow.min.js', array( 'jquery' ), 'v1.3.0 ', false );

	wp_enqueue_script( 'buzz-agency-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20151215', true );

	wp_enqueue_script( 'buzz-agency-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	wp_localize_script('buzz-agency-custom', 'buzz_agency_script_vars', array(
		'ajaxurl' => site_url() . '/wp-admin/admin-ajax.php', // WordPress AJAX
		'current_page' => get_query_var( 'paged' ) ? get_query_var('paged') : 1,
	));

	//custom
	wp_enqueue_script( 'buzz-agency-custom', get_template_directory_uri() . '/assets/js/custom.js', array('jquery'), '1.0.0', true );
}
add_action( 'wp_enqueue_scripts', 'buzz_agency_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load  Custom Customizer Functions File.
 */
require get_template_directory() . '/inc/customizer/customizer-options.php';


/**
 * Load  Sanitizer Functions File.
 */
require get_template_directory() . '/inc/customizer/sanitizer.php';

/**
 * Load  Functions File.
 */
require get_template_directory() . '/inc/functions/custom-functions.php';

/**
 * Load Font List Functions File.
 */
require get_template_directory() . '/inc/functions/font-awesome-list.php';

/**
 * Header  Sections Functions
 */
require get_template_directory() . '/inc/hooks/top-header-hook.php';

/**
 * Metabox  Functions
 */
require get_template_directory() . '/inc/metabox.php';

/** 
 * TGM Plugins Activations  
**/
require get_template_directory() . '/inc/class-tgm-plugin-activation.php';

/**
 * Slider Sections Functions
 */
require get_template_directory() . '/inc/hooks/sections/section-slider.php';

/**
 * Feature Sections Functions
 */
require get_template_directory() . '/inc/hooks/sections/section-feature.php';

/**
 * About Sections Functions
 */
require get_template_directory() . '/inc/hooks/sections/section-about.php';

/**
 * Counter Sections Functions
 */
require get_template_directory() . '/inc/hooks/sections/section-counter.php';

/**
 * Process Sections Functions
 */
require get_template_directory() . '/inc/hooks/sections/section-process.php';

/**
 * Client Sections Functions
 */
require get_template_directory() . '/inc/hooks/sections/section-client.php';

/**
 * Testimonial Sections Functions
 */
require get_template_directory() . '/inc/hooks/sections/section-testimonial.php';

/**
 * Service Sections Functions
 */
require get_template_directory() . '/inc/hooks/sections/section-service.php';

/**
 * Buzz Agency Sections Functions
 */
require get_template_directory() . '/inc/hooks/buzz-agency-footer-hook.php';

/**
 * Buzz Agency Breadcrumbs  Functions
 */
require get_template_directory() . '/inc/breadcrumbs.php';

/**
 * Buzz Agency Form  Functions
 */
require get_template_directory() . '/inc/functions/search-form.php';


/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}
