<?php
/**
 * The main template file
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package Buzz_Agency
 */

get_header();
?>
<div class="container">
	<div class="row">
		<?php
			
			global $post;

			$buzz_agency_sidebar = get_post_meta($post->ID, 'buzz_agency_sidebar_layout', true);
			if ( empty( $buzz_agency_sidebar ) ){
				$buzz_agency_sidebar = 'right-sidebar';
			}
			$buzz_agency_custom_class = 'custom-col-8';
			if( 'no-sidebar' == $buzz_agency_sidebar ){
				$buzz_agency_custom_class = 'custom-col-12';
			} elseif ( 'both-sidebar' == $buzz_agency_sidebar ) {
				$buzz_agency_custom_class = 'custom-col-4';
			}else{
				$buzz_agency_custom_class = 'custom-col-8';
			}
			
			if($buzz_agency_sidebar=='both-sidebar' || $buzz_agency_sidebar=='left-sidebar'){
				get_sidebar('left');
			} 

			if($buzz_agency_sidebar=='both-sidebar' || $buzz_agency_sidebar=='right-sidebar'){
				get_sidebar();
			}
		?>

		<div id="primary" class="content-area <?php echo esc_attr( $buzz_agency_custom_class );?>  ">

			<main id="main" class="site-main">

				<?php
				if ( have_posts() ) :

					if ( is_home() && ! is_front_page() ) :
						?>
						<header>
							<h1 class="page-title screen-reader-text"><?php single_post_title(); ?></h1>
						</header>
						<?php
					endif;

					/* Start the Loop */
					while ( have_posts() ) :
						the_post();

						/*
						 * Include the Post-Type-specific template for the content.
						 * If you want to override this in a child theme, then include a file
						 * called content-___.php (where ___ is the Post Type name) and that will be used instead.
						 */
						get_template_part( 'template-parts/content', get_post_type() );

					endwhile;

					do_action( 'buzz_agency_action_navigation' );

				else :

					get_template_part( 'template-parts/content', 'none' );

				endif;
				?>

			</main><!-- #main -->

		</div><!-- #primary -->		
	</div>


</div>

<?php get_footer();
